@@ -723,7 +723,7 @@ def get_flux_dist(image):
 
     return(dist)
     
-def mag_dist(mag_l, mag_u, exp_time=30, pix_size=1.24):
+def mag_dist(mag_l, mag_u, exp_time=30, pix_size=1.24, CF = 8.79*10**9):
     """
     Ry Cutter 2019
     
@@ -748,7 +748,7 @@ def mag_dist(mag_l, mag_u, exp_time=30, pix_size=1.24):
     for i in range(50):
         mag = mag_l+mag_step*i
         dist[i][0] = 1./50.
-        dist[i][1] = 10**(-mag/2.5) * 8.79*10**9 / (exp_time * pix_size)
+        dist[i][1] = 10**(-mag/2.5) * CF* (exp_time * pix_size)
 
     return(dist)
 
@@ -958,7 +958,7 @@ def inject_fake_stars(image, n_stars, grid, flux_dist, PSF_mod, write_cat, x_p,
     return(image_dat)
 
 
-def write_mag(exp_time=30, pix_size=1.24):
+def write_mag(exp_time=30, pix_size=1.24, CF = 8.79*10**9):
     """
     Ry Cutter 2019
 
@@ -972,7 +972,7 @@ def write_mag(exp_time=30, pix_size=1.24):
     """
 
     pix_size = pix_size*10**-4
-    C =  8.79*10**9 / (exp_time * pix_size)
+    C =  CF * (exp_time * pix_size)
     new_cat = open('mags.cat', 'w')
     for lin in open('injection.cat', 'r'):
         tmp = lin.split()
